@@ -101,12 +101,12 @@ PolySet2SpatialPolygons <- function(PS, close_polys=TRUE) {
     if (is.null(prj)) stop("unknown coordinate reference system")
     if (prj == "LL") p4s <- "+proj=longlat"
     else if (prj == "UTM") {
-# zone placing changed
+# apparent change in PBS object attributes
         zn <- attr(prj, "zone")
         if (is.null(zn)) zn <- attr(PS, "zone")
-        p4s <- paste("+proj=utm +zone=", zn, sep="")
-    }
-    else stop("unknown coordinate reference system")
+        if (is.null(zn)) stop("no valid zone attribute")
+	p4s <- paste("+proj=utm +zone=", zn, sep="")
+    } else stop("unknown coordinate reference system")
     hasPID <- "PID" %in% names(PS)
     if (!hasPID) stop("object does not have PID column")
     res0 <- split(PS, PS$PID)
